"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SupportedMethods(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METHODS_FIELD_NUMBER: builtins.int
    EVENT_STORE_SERVER_VERSION_FIELD_NUMBER: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SupportedMethod]: ...
    event_store_server_version: builtins.str
    def __init__(
        self,
        *,
        methods: collections.abc.Iterable[global___SupportedMethod] | None = ...,
        event_store_server_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_store_server_version", b"event_store_server_version", "methods", b"methods"]) -> None: ...

global___SupportedMethods = SupportedMethods

class SupportedMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METHOD_NAME_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    method_name: builtins.str
    service_name: builtins.str
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        method_name: builtins.str = ...,
        service_name: builtins.str = ...,
        features: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["features", b"features", "method_name", b"method_name", "service_name", b"service_name"]) -> None: ...

global___SupportedMethod = SupportedMethod



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10monitoring.proto\x12\x1d\x65vent_store.client.monitoring\"C\n\x08StatsReq\x12\x14\n\x0cuse_metadata\x18\x01 \x01(\x08\x12!\n\x19refresh_time_period_in_ms\x18\x04 \x01(\x04\"}\n\tStatsResp\x12\x42\n\x05stats\x18\x01 \x03(\x0b\x32\x33.event_store.client.monitoring.StatsResp.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32j\n\nMonitoring\x12\\\n\x05Stats\x12\'.event_store.client.monitoring.StatsReq\x1a(.event_store.client.monitoring.StatsResp0\x01\x42*\n(com.eventstore.dbclient.proto.monitoringb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'monitoring_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.eventstore.dbclient.proto.monitoring'
  _STATSRESP_STATSENTRY._options = None
  _STATSRESP_STATSENTRY._serialized_options = b'8\001'
  _STATSREQ._serialized_start=51
  _STATSREQ._serialized_end=118
  _STATSRESP._serialized_start=120
  _STATSRESP._serialized_end=245
  _STATSRESP_STATSENTRY._serialized_start=201
  _STATSRESP_STATSENTRY._serialized_end=245
  _MONITORING._serialized_start=247
  _MONITORING._serialized_end=353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: streams.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import shared_pb2 as shared__pb2
from . import status_pb2 as status__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rstreams.proto\x12\x1a\x65vent_store.client.streams\x1a\x0cshared.proto\x1a\x0cstatus.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x0e\n\x07ReadReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.streams.ReadReq.Options\x1a\xe3\r\n\x07Options\x12K\n\x06stream\x18\x01 \x01(\x0b\x32\x39.event_store.client.streams.ReadReq.Options.StreamOptionsH\x00\x12\x45\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x36.event_store.client.streams.ReadReq.Options.AllOptionsH\x00\x12Q\n\x0eread_direction\x18\x03 \x01(\x0e\x32\x39.event_store.client.streams.ReadReq.Options.ReadDirection\x12\x15\n\rresolve_links\x18\x04 \x01(\x08\x12\x0f\n\x05\x63ount\x18\x05 \x01(\x04H\x01\x12W\n\x0csubscription\x18\x06 \x01(\x0b\x32?.event_store.client.streams.ReadReq.Options.SubscriptionOptionsH\x01\x12K\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x39.event_store.client.streams.ReadReq.Options.FilterOptionsH\x02\x12.\n\tno_filter\x18\x08 \x01(\x0b\x32\x19.event_store.client.EmptyH\x02\x12K\n\x0buuid_option\x18\t \x01(\x0b\x32\x36.event_store.client.streams.ReadReq.Options.UUIDOption\x12Q\n\x0e\x63ontrol_option\x18\n \x01(\x0b\x32\x39.event_store.client.streams.ReadReq.Options.ControlOption\x1a\xcd\x01\n\rStreamOptions\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02 \x01(\x04H\x00\x12*\n\x05start\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x11\n\x0frevision_option\x1a\xba\x01\n\nAllOptions\x12H\n\x08position\x18\x01 \x01(\x0b\x32\x34.event_store.client.streams.ReadReq.Options.PositionH\x00\x12*\n\x05start\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x0c\n\nall_option\x1a\x15\n\x13SubscriptionOptions\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x1a\xf0\x02\n\rFilterOptions\x12\x61\n\x11stream_identifier\x18\x01 \x01(\x0b\x32\x44.event_store.client.streams.ReadReq.Options.FilterOptions.ExpressionH\x00\x12Z\n\nevent_type\x18\x02 \x01(\x0b\x32\x44.event_store.client.streams.ReadReq.Options.FilterOptions.ExpressionH\x00\x12\r\n\x03max\x18\x03 \x01(\rH\x01\x12*\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12$\n\x1c\x63heckpointIntervalMultiplier\x18\x05 \x01(\r\x1a+\n\nExpression\x12\r\n\x05regex\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x03(\tB\x08\n\x06\x66ilterB\x08\n\x06window\x1au\n\nUUIDOption\x12/\n\nstructured\x18\x01 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12+\n\x06string\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\t\n\x07\x63ontent\x1a&\n\rControlOption\x12\x15\n\rcompatibility\x18\x01 \x01(\r\",\n\rReadDirection\x12\x0c\n\x08\x46orwards\x10\x00\x12\r\n\tBackwards\x10\x01\x42\x0f\n\rstream_optionB\x0e\n\x0c\x63ount_optionB\x0f\n\rfilter_option\"\x95\n\n\x08ReadResp\x12?\n\x05\x65vent\x18\x01 \x01(\x0b\x32..event_store.client.streams.ReadResp.ReadEventH\x00\x12U\n\x0c\x63onfirmation\x18\x02 \x01(\x0b\x32=.event_store.client.streams.ReadResp.SubscriptionConfirmationH\x00\x12\x45\n\ncheckpoint\x18\x03 \x01(\x0b\x32/.event_store.client.streams.ReadResp.CheckpointH\x00\x12O\n\x10stream_not_found\x18\x04 \x01(\x0b\x32\x33.event_store.client.streams.ReadResp.StreamNotFoundH\x00\x12\x1f\n\x15\x66irst_stream_position\x18\x05 \x01(\x04H\x00\x12\x1e\n\x14last_stream_position\x18\x06 \x01(\x04H\x00\x12I\n\x18last_all_stream_position\x18\x07 \x01(\x0b\x32%.event_store.client.AllStreamPositionH\x00\x1a\xf8\x04\n\tReadEvent\x12K\n\x05\x65vent\x18\x01 \x01(\x0b\x32<.event_store.client.streams.ReadResp.ReadEvent.RecordedEvent\x12J\n\x04link\x18\x02 \x01(\x0b\x32<.event_store.client.streams.ReadResp.ReadEvent.RecordedEvent\x12\x19\n\x0f\x63ommit_position\x18\x03 \x01(\x04H\x00\x12\x30\n\x0bno_position\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x1a\xf8\x02\n\rRecordedEvent\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12?\n\x11stream_identifier\x18\x02 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x17\n\x0fstream_revision\x18\x03 \x01(\x04\x12\x18\n\x10prepare_position\x18\x04 \x01(\x04\x12\x17\n\x0f\x63ommit_position\x18\x05 \x01(\x04\x12\\\n\x08metadata\x18\x06 \x03(\x0b\x32J.event_store.client.streams.ReadResp.ReadEvent.RecordedEvent.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x07 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08position\x1a\x33\n\x18SubscriptionConfirmation\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\x1a?\n\nCheckpoint\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x1aQ\n\x0eStreamNotFound\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierB\t\n\x07\x63ontent\"\x9f\x05\n\tAppendReq\x12@\n\x07options\x18\x01 \x01(\x0b\x32-.event_store.client.streams.AppendReq.OptionsH\x00\x12Q\n\x10proposed_message\x18\x02 \x01(\x0b\x32\x35.event_store.client.streams.AppendReq.ProposedMessageH\x00\x1a\x88\x02\n\x07Options\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02 \x01(\x04H\x00\x12.\n\tno_stream\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x61ny\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x32\n\rstream_exists\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x1a\n\x18\x65xpected_stream_revision\x1a\xe6\x01\n\x0fProposedMessage\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12U\n\x08metadata\x18\x02 \x03(\x0b\x32\x43.event_store.client.streams.AppendReq.ProposedMessage.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x63ontent\"\x8d\t\n\nAppendResp\x12\x41\n\x07success\x18\x01 \x01(\x0b\x32..event_store.client.streams.AppendResp.SuccessH\x00\x12]\n\x16wrong_expected_version\x18\x02 \x01(\x0b\x32;.event_store.client.streams.AppendResp.WrongExpectedVersionH\x00\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x1a\xfa\x01\n\x07Success\x12\x1a\n\x10\x63urrent_revision\x18\x01 \x01(\x04H\x00\x12.\n\tno_stream\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x43\n\x08position\x18\x03 \x01(\x0b\x32/.event_store.client.streams.AppendResp.PositionH\x01\x12\x30\n\x0bno_position\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x42\x19\n\x17\x63urrent_revision_optionB\x11\n\x0fposition_option\x1a\x96\x05\n\x14WrongExpectedVersion\x12!\n\x17\x63urrent_revision_20_6_0\x18\x01 \x01(\x04H\x00\x12\x35\n\x10no_stream_20_6_0\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\"\n\x18\x65xpected_revision_20_6_0\x18\x03 \x01(\x04H\x01\x12/\n\nany_20_6_0\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12\x39\n\x14stream_exists_20_6_0\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12\x1a\n\x10\x63urrent_revision\x18\x06 \x01(\x04H\x02\x12\x36\n\x11\x63urrent_no_stream\x18\x07 \x01(\x0b\x32\x19.event_store.client.EmptyH\x02\x12\x1b\n\x11\x65xpected_revision\x18\x08 \x01(\x04H\x03\x12\x31\n\x0c\x65xpected_any\x18\t \x01(\x0b\x32\x19.event_store.client.EmptyH\x03\x12;\n\x16\x65xpected_stream_exists\x18\n \x01(\x0b\x32\x19.event_store.client.EmptyH\x03\x12\x37\n\x12\x65xpected_no_stream\x18\x0b \x01(\x0b\x32\x19.event_store.client.EmptyH\x03\x42 \n\x1e\x63urrent_revision_option_20_6_0B!\n\x1f\x65xpected_revision_option_20_6_0B\x19\n\x17\x63urrent_revision_optionB\x1a\n\x18\x65xpected_revision_optionB\x08\n\x06result\"\xe1\x06\n\x0e\x42\x61tchAppendReq\x12\x30\n\x0e\x63orrelation_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x43\n\x07options\x18\x02 \x01(\x0b\x32\x32.event_store.client.streams.BatchAppendReq.Options\x12U\n\x11proposed_messages\x18\x03 \x03(\x0b\x32:.event_store.client.streams.BatchAppendReq.ProposedMessage\x12\x10\n\x08is_final\x18\x04 \x01(\x08\x1a\x80\x03\n\x07Options\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x19\n\x0fstream_position\x18\x02 \x01(\x04H\x00\x12+\n\tno_stream\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12%\n\x03\x61ny\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rstream_exists\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x36\n\x10\x64\x65\x61\x64line_21_10_0\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x12-\n\x08\x64\x65\x61\x64line\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationH\x01\x42\x1a\n\x18\x65xpected_stream_positionB\x11\n\x0f\x64\x65\x61\x64line_option\x1a\xeb\x01\n\x0fProposedMessage\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12Z\n\x08metadata\x18\x02 \x03(\x0b\x32H.event_store.client.streams.BatchAppendReq.ProposedMessage.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x05\n\x0f\x42\x61tchAppendResp\x12\x30\n\x0e\x63orrelation_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12#\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x12\x46\n\x07success\x18\x03 \x01(\x0b\x32\x33.event_store.client.streams.BatchAppendResp.SuccessH\x00\x12?\n\x11stream_identifier\x18\x04 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x19\n\x0fstream_position\x18\x05 \x01(\x04H\x01\x12+\n\tno_stream\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12%\n\x03\x61ny\x18\x07 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12/\n\rstream_exists\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x1a\xea\x01\n\x07Success\x12\x1a\n\x10\x63urrent_revision\x18\x01 \x01(\x04H\x00\x12+\n\tno_stream\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x39\n\x08position\x18\x03 \x01(\x0b\x32%.event_store.client.AllStreamPositionH\x01\x12-\n\x0bno_position\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x42\x19\n\x17\x63urrent_revision_optionB\x11\n\x0fposition_optionB\x08\n\x06resultB\x1a\n\x18\x65xpected_stream_position\"\xd6\x02\n\tDeleteReq\x12>\n\x07options\x18\x01 \x01(\x0b\x32-.event_store.client.streams.DeleteReq.Options\x1a\x88\x02\n\x07Options\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02 \x01(\x04H\x00\x12.\n\tno_stream\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x61ny\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x32\n\rstream_exists\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x1a\n\x18\x65xpected_stream_revision\"\xd5\x01\n\nDeleteResp\x12\x43\n\x08position\x18\x01 \x01(\x0b\x32/.event_store.client.streams.DeleteResp.PositionH\x00\x12\x30\n\x0bno_position\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x42\x11\n\x0fposition_option\"\xdc\x02\n\x0cTombstoneReq\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.event_store.client.streams.TombstoneReq.Options\x1a\x88\x02\n\x07Options\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02 \x01(\x04H\x00\x12.\n\tno_stream\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x61ny\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x32\n\rstream_exists\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x1a\n\x18\x65xpected_stream_revision\"\xdb\x01\n\rTombstoneResp\x12\x46\n\x08position\x18\x01 \x01(\x0b\x32\x32.event_store.client.streams.TombstoneResp.PositionH\x00\x12\x30\n\x0bno_position\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x42\x11\n\x0fposition_option2\xe0\x03\n\x07Streams\x12S\n\x04Read\x12#.event_store.client.streams.ReadReq\x1a$.event_store.client.streams.ReadResp0\x01\x12Y\n\x06\x41ppend\x12%.event_store.client.streams.AppendReq\x1a&.event_store.client.streams.AppendResp(\x01\x12W\n\x06\x44\x65lete\x12%.event_store.client.streams.DeleteReq\x1a&.event_store.client.streams.DeleteResp\x12`\n\tTombstone\x12(.event_store.client.streams.TombstoneReq\x1a).event_store.client.streams.TombstoneResp\x12j\n\x0b\x42\x61tchAppend\x12*.event_store.client.streams.BatchAppendReq\x1a+.event_store.client.streams.BatchAppendResp(\x01\x30\x01\x42\'\n%com.eventstore.dbclient.proto.streamsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'streams_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.eventstore.dbclient.proto.streams'
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._options = None
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_options = b'8\001'
  _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._options = None
  _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_options = b'8\001'
  _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._options = None
  _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_options = b'8\001'
  _READREQ._serialized_start=168
  _READREQ._serialized_end=2005
  _READREQ_OPTIONS._serialized_start=242
  _READREQ_OPTIONS._serialized_end=2005
  _READREQ_OPTIONS_STREAMOPTIONS._serialized_start=899
  _READREQ_OPTIONS_STREAMOPTIONS._serialized_end=1104
  _READREQ_OPTIONS_ALLOPTIONS._serialized_start=1107
  _READREQ_OPTIONS_ALLOPTIONS._serialized_end=1293
  _READREQ_OPTIONS_SUBSCRIPTIONOPTIONS._serialized_start=1295
  _READREQ_OPTIONS_SUBSCRIPTIONOPTIONS._serialized_end=1316
  _READREQ_OPTIONS_POSITION._serialized_start=1318
  _READREQ_OPTIONS_POSITION._serialized_end=1379
  _READREQ_OPTIONS_FILTEROPTIONS._serialized_start=1382
  _READREQ_OPTIONS_FILTEROPTIONS._serialized_end=1750
  _READREQ_OPTIONS_FILTEROPTIONS_EXPRESSION._serialized_start=1687
  _READREQ_OPTIONS_FILTEROPTIONS_EXPRESSION._serialized_end=1730
  _READREQ_OPTIONS_UUIDOPTION._serialized_start=1752
  _READREQ_OPTIONS_UUIDOPTION._serialized_end=1869
  _READREQ_OPTIONS_CONTROLOPTION._serialized_start=1871
  _READREQ_OPTIONS_CONTROLOPTION._serialized_end=1909
  _READREQ_OPTIONS_READDIRECTION._serialized_start=1911
  _READREQ_OPTIONS_READDIRECTION._serialized_end=1955
  _READRESP._serialized_start=2008
  _READRESP._serialized_end=3309
  _READRESP_READEVENT._serialized_start=2465
  _READRESP_READEVENT._serialized_end=3097
  _READRESP_READEVENT_RECORDEDEVENT._serialized_start=2709
  _READRESP_READEVENT_RECORDEDEVENT._serialized_end=3085
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_start=3038
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_end=3085
  _READRESP_SUBSCRIPTIONCONFIRMATION._serialized_start=3099
  _READRESP_SUBSCRIPTIONCONFIRMATION._serialized_end=3150
  _READRESP_CHECKPOINT._serialized_start=3152
  _READRESP_CHECKPOINT._serialized_end=3215
  _READRESP_STREAMNOTFOUND._serialized_start=3217
  _READRESP_STREAMNOTFOUND._serialized_end=3298
  _APPENDREQ._serialized_start=3312
  _APPENDREQ._serialized_end=3983
  _APPENDREQ_OPTIONS._serialized_start=3475
  _APPENDREQ_OPTIONS._serialized_end=3739
  _APPENDREQ_PROPOSEDMESSAGE._serialized_start=3742
  _APPENDREQ_PROPOSEDMESSAGE._serialized_end=3972
  _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_start=3038
  _APPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_end=3085
  _APPENDRESP._serialized_start=3986
  _APPENDRESP._serialized_end=5151
  _APPENDRESP_POSITION._serialized_start=1318
  _APPENDRESP_POSITION._serialized_end=1379
  _APPENDRESP_SUCCESS._serialized_start=4226
  _APPENDRESP_SUCCESS._serialized_end=4476
  _APPENDRESP_WRONGEXPECTEDVERSION._serialized_start=4479
  _APPENDRESP_WRONGEXPECTEDVERSION._serialized_end=5141
  _BATCHAPPENDREQ._serialized_start=5154
  _BATCHAPPENDREQ._serialized_end=6019
  _BATCHAPPENDREQ_OPTIONS._serialized_start=5397
  _BATCHAPPENDREQ_OPTIONS._serialized_end=5781
  _BATCHAPPENDREQ_PROPOSEDMESSAGE._serialized_start=5784
  _BATCHAPPENDREQ_PROPOSEDMESSAGE._serialized_end=6019
  _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_start=3038
  _BATCHAPPENDREQ_PROPOSEDMESSAGE_METADATAENTRY._serialized_end=3085
  _BATCHAPPENDRESP._serialized_start=6022
  _BATCHAPPENDRESP._serialized_end=6698
  _BATCHAPPENDRESP_SUCCESS._serialized_start=6426
  _BATCHAPPENDRESP_SUCCESS._serialized_end=6660
  _DELETEREQ._serialized_start=6701
  _DELETEREQ._serialized_end=7043
  _DELETEREQ_OPTIONS._serialized_start=3475
  _DELETEREQ_OPTIONS._serialized_end=3739
  _DELETERESP._serialized_start=7046
  _DELETERESP._serialized_end=7259
  _DELETERESP_POSITION._serialized_start=1318
  _DELETERESP_POSITION._serialized_end=1379
  _TOMBSTONEREQ._serialized_start=7262
  _TOMBSTONEREQ._serialized_end=7610
  _TOMBSTONEREQ_OPTIONS._serialized_start=3475
  _TOMBSTONEREQ_OPTIONS._serialized_end=3739
  _TOMBSTONERESP._serialized_start=7613
  _TOMBSTONERESP._serialized_end=7832
  _TOMBSTONERESP_POSITION._serialized_start=1318
  _TOMBSTONERESP_POSITION._serialized_end=1379
  _STREAMS._serialized_start=7835
  _STREAMS._serialized_end=8315
# @@protoc_insertion_point(module_scope)



import enum
from dataclasses import dataclass
from typing import Optional, Type, TypeVar

from esdb.generated.persistent_pb2 import CreateReq
from esdb.generated.shared_pb2 import Empty
from esdb.generated.streams_pb2 import ReadReq

MessageType = TypeVar("MessageType", ReadReq.Options.FilterOptions, CreateReq.AllOptions.FilterOptions)


@dataclass
class Filter:
    class Kind(enum.Enum):
        STREAM = "stream"
        EVENT_TYPE = "event_type"

    kind: Kind
    regex: str
    prefixes: Optional[list[str]] = None
    checkpoint_interval_multiplier: Optional[int] = None

    def to_protobuf(self, message_type: Type[MessageType]) -> MessageType:
        expression_type = message_type.Expression
        stream_identifier = None
        event_type = None
        if self.kind == self.Kind.STREAM:
            stream_identifier = expression_type(regex=self.regex, prefix=self.prefixes)
        elif self.kind == self.Kind.EVENT_TYPE:
            event_type = expression_type(regex=self.regex, prefix=self.prefixes)
        options = message_type(
            stream_identifier=stream_identifier,
            event_type=event_type,
            max=0,  # TODO: This apparently does nothing ¯\_(ツ)_/¯
            count=Empty(),
        )
        if self.checkpoint_interval_multiplier:
            options.checkpointIntervalMultiplier = self.checkpoint_interval_multiplier
        return options



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: users.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0busers.proto\x12\x18\x65vent_store.client.users\"\x9d\x01\n\tCreateReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.CreateReq.Options\x1aR\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\x12\x0e\n\x06groups\x18\x04 \x03(\t\"\x0c\n\nCreateResp\"\x9d\x01\n\tUpdateReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.UpdateReq.Options\x1aR\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\x12\x0e\n\x06groups\x18\x04 \x03(\t\"\x0c\n\nUpdateResp\"h\n\tDeleteReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.DeleteReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\x0c\n\nDeleteResp\"h\n\tEnableReq\x12<\n\x07options\x18\x01 \x01(\x0b\x32+.event_store.client.users.EnableReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\x0c\n\nEnableResp\"j\n\nDisableReq\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.event_store.client.users.DisableReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\r\n\x0b\x44isableResp\"j\n\nDetailsReq\x12=\n\x07options\x18\x01 \x01(\x0b\x32,.event_store.client.users.DetailsReq.Options\x1a\x1d\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\"\xa8\x02\n\x0b\x44\x65tailsResp\x12G\n\x0cuser_details\x18\x01 \x01(\x0b\x32\x31.event_store.client.users.DetailsResp.UserDetails\x1a\xcf\x01\n\x0bUserDetails\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12P\n\x0clast_updated\x18\x04 \x01(\x0b\x32:.event_store.client.users.DetailsResp.UserDetails.DateTime\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x1a%\n\x08\x44\x61teTime\x12\x19\n\x11ticks_since_epoch\x18\x01 \x01(\x03\"\xa8\x01\n\x11\x43hangePasswordReq\x12\x44\n\x07options\x18\x01 \x01(\x0b\x32\x33.event_store.client.users.ChangePasswordReq.Options\x1aM\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x18\n\x10\x63urrent_password\x18\x02 \x01(\t\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\"\x14\n\x12\x43hangePasswordResp\"\x8c\x01\n\x10ResetPasswordReq\x12\x43\n\x07options\x18\x01 \x01(\x0b\x32\x32.event_store.client.users.ResetPasswordReq.Options\x1a\x33\n\x07Options\x12\x12\n\nlogin_name\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"\x13\n\x11ResetPasswordResp2\xe4\x05\n\x05Users\x12S\n\x06\x43reate\x12#.event_store.client.users.CreateReq\x1a$.event_store.client.users.CreateResp\x12S\n\x06Update\x12#.event_store.client.users.UpdateReq\x1a$.event_store.client.users.UpdateResp\x12S\n\x06\x44\x65lete\x12#.event_store.client.users.DeleteReq\x1a$.event_store.client.users.DeleteResp\x12V\n\x07\x44isable\x12$.event_store.client.users.DisableReq\x1a%.event_store.client.users.DisableResp\x12S\n\x06\x45nable\x12#.event_store.client.users.EnableReq\x1a$.event_store.client.users.EnableResp\x12X\n\x07\x44\x65tails\x12$.event_store.client.users.DetailsReq\x1a%.event_store.client.users.DetailsResp0\x01\x12k\n\x0e\x43hangePassword\x12+.event_store.client.users.ChangePasswordReq\x1a,.event_store.client.users.ChangePasswordResp\x12h\n\rResetPassword\x12*.event_store.client.users.ResetPasswordReq\x1a+.event_store.client.users.ResetPasswordRespB%\n#com.eventstore.dbclient.proto.usersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'users_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.eventstore.dbclient.proto.users'
  _CREATEREQ._serialized_start=42
  _CREATEREQ._serialized_end=199
  _CREATEREQ_OPTIONS._serialized_start=117
  _CREATEREQ_OPTIONS._serialized_end=199
  _CREATERESP._serialized_start=201
  _CREATERESP._serialized_end=213
  _UPDATEREQ._serialized_start=216
  _UPDATEREQ._serialized_end=373
  _UPDATEREQ_OPTIONS._serialized_start=117
  _UPDATEREQ_OPTIONS._serialized_end=199
  _UPDATERESP._serialized_start=375
  _UPDATERESP._serialized_end=387
  _DELETEREQ._serialized_start=389
  _DELETEREQ._serialized_end=493
  _DELETEREQ_OPTIONS._serialized_start=117
  _DELETEREQ_OPTIONS._serialized_end=146
  _DELETERESP._serialized_start=495
  _DELETERESP._serialized_end=507
  _ENABLEREQ._serialized_start=509
  _ENABLEREQ._serialized_end=613
  _ENABLEREQ_OPTIONS._serialized_start=117
  _ENABLEREQ_OPTIONS._serialized_end=146
  _ENABLERESP._serialized_start=615
  _ENABLERESP._serialized_end=627
  _DISABLEREQ._serialized_start=629
  _DISABLEREQ._serialized_end=735
  _DISABLEREQ_OPTIONS._serialized_start=117
  _DISABLEREQ_OPTIONS._serialized_end=146
  _DISABLERESP._serialized_start=737
  _DISABLERESP._serialized_end=750
  _DETAILSREQ._serialized_start=752
  _DETAILSREQ._serialized_end=858
  _DETAILSREQ_OPTIONS._serialized_start=117
  _DETAILSREQ_OPTIONS._serialized_end=146
  _DETAILSRESP._serialized_start=861
  _DETAILSRESP._serialized_end=1157
  _DETAILSRESP_USERDETAILS._serialized_start=950
  _DETAILSRESP_USERDETAILS._serialized_end=1157
  _DETAILSRESP_USERDETAILS_DATETIME._serialized_start=1120
  _DETAILSRESP_USERDETAILS_DATETIME._serialized_end=1157
  _CHANGEPASSWORDREQ._serialized_start=1160
  _CHANGEPASSWORDREQ._serialized_end=1328
  _CHANGEPASSWORDREQ_OPTIONS._serialized_start=1251
  _CHANGEPASSWORDREQ_OPTIONS._serialized_end=1328
  _CHANGEPASSWORDRESP._serialized_start=1330
  _CHANGEPASSWORDRESP._serialized_end=1350
  _RESETPASSWORDREQ._serialized_start=1353
  _RESETPASSWORDREQ._serialized_end=1493
  _RESETPASSWORDREQ_OPTIONS._serialized_start=1442
  _RESETPASSWORDREQ_OPTIONS._serialized_end=1493
  _RESETPASSWORDRESP._serialized_start=1495
  _RESETPASSWORDRESP._serialized_end=1514
  _USERS._serialized_start=1517
  _USERS._serialized_end=2257
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.struct_pb2
import shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class Transient(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            NAME_FIELD_NUMBER: builtins.int
            name: builtins.str
            def __init__(
                self,
                *,
                name: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

        class Continuous(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            NAME_FIELD_NUMBER: builtins.int
            EMIT_ENABLED_FIELD_NUMBER: builtins.int
            TRACK_EMITTED_STREAMS_FIELD_NUMBER: builtins.int
            name: builtins.str
            emit_enabled: builtins.bool
            track_emitted_streams: builtins.bool
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                emit_enabled: builtins.bool = ...,
                track_emitted_streams: builtins.bool = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["emit_enabled", b"emit_enabled", "name", b"name", "track_emitted_streams", b"track_emitted_streams"]) -> None: ...

        ONE_TIME_FIELD_NUMBER: builtins.int
        TRANSIENT_FIELD_NUMBER: builtins.int
        CONTINUOUS_FIELD_NUMBER: builtins.int
        QUERY_FIELD_NUMBER: builtins.int
        @property
        def one_time(self) -> shared_pb2.Empty: ...
        @property
        def transient(self) -> global___CreateReq.Options.Transient: ...
        @property
        def continuous(self) -> global___CreateReq.Options.Continuous: ...
        query: builtins.str
        def __init__(
            self,
            *,
            one_time: shared_pb2.Empty | None = ...,
            transient: global___CreateReq.Options.Transient | None = ...,
            continuous: global___CreateReq.Options.Continuous | None = ...,
            query: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["continuous", b"continuous", "mode", b"mode", "one_time", b"one_time", "transient", b"transient"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["continuous", b"continuous", "mode", b"mode", "one_time", b"one_time", "query", b"query", "transient", b"transient"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["mode", b"mode"]) -> typing_extensions.Literal["one_time", "transient", "continuous"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___CreateReq.Options: ...
    def __init__(
        self,
        *,
        options: global___CreateReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___CreateReq = CreateReq

class CreateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateResp = CreateResp

class UpdateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        QUERY_FIELD_NUMBER: builtins.int
        EMIT_ENABLED_FIELD_NUMBER: builtins.int
        NO_EMIT_OPTIONS_FIELD_NUMBER: builtins.int
        name: builtins.str
        query: builtins.str
        emit_enabled: builtins.bool
        @property
        def no_emit_options(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            query: builtins.str = ...,
            emit_enabled: builtins.bool = ...,
            no_emit_options: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["emit_enabled", b"emit_enabled", "emit_option", b"emit_option", "no_emit_options", b"no_emit_options"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["emit_enabled", b"emit_enabled", "emit_option", b"emit_option", "name", b"name", "no_emit_options", b"no_emit_options", "query", b"query"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["emit_option", b"emit_option"]) -> typing_extensions.Literal["emit_enabled", "no_emit_options"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___UpdateReq.Options: ...
    def __init__(
        self,
        *,
        options: global___UpdateReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___UpdateReq = UpdateReq

class UpdateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateResp = UpdateResp

class DeleteReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        DELETE_EMITTED_STREAMS_FIELD_NUMBER: builtins.int
        DELETE_STATE_STREAM_FIELD_NUMBER: builtins.int
        DELETE_CHECKPOINT_STREAM_FIELD_NUMBER: builtins.int
        name: builtins.str
        delete_emitted_streams: builtins.bool
        delete_state_stream: builtins.bool
        delete_checkpoint_stream: builtins.bool
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            delete_emitted_streams: builtins.bool = ...,
            delete_state_stream: builtins.bool = ...,
            delete_checkpoint_stream: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["delete_checkpoint_stream", b"delete_checkpoint_stream", "delete_emitted_streams", b"delete_emitted_streams", "delete_state_stream", b"delete_state_stream", "name", b"name"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___DeleteReq.Options: ...
    def __init__(
        self,
        *,
        options: global___DeleteReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___DeleteReq = DeleteReq

class DeleteResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteResp = DeleteResp

class StatisticsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        ALL_FIELD_NUMBER: builtins.int
        TRANSIENT_FIELD_NUMBER: builtins.int
        CONTINUOUS_FIELD_NUMBER: builtins.int
        ONE_TIME_FIELD_NUMBER: builtins.int
        name: builtins.str
        @property
        def all(self) -> shared_pb2.Empty: ...
        @property
        def transient(self) -> shared_pb2.Empty: ...
        @property
        def continuous(self) -> shared_pb2.Empty: ...
        @property
        def one_time(self) -> shared_pb2.Empty: ...
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            all: shared_pb2.Empty | None = ...,
            transient: shared_pb2.Empty | None = ...,
            continuous: shared_pb2.Empty | None = ...,
            one_time: shared_pb2.Empty | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["all", b"all", "continuous", b"continuous", "mode", b"mode", "name", b"name", "one_time", b"one_time", "transient", b"transient"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["all", b"all", "continuous", b"continuous", "mode", b"mode", "name", b"name", "one_time", b"one_time", "transient", b"transient"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["mode", b"mode"]) -> typing_extensions.Literal["name", "all", "transient", "continuous", "one_time"] | None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___StatisticsReq.Options: ...
    def __init__(
        self,
        *,
        options: global___StatisticsReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___StatisticsReq = StatisticsReq

class StatisticsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Details(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COREPROCESSINGTIME_FIELD_NUMBER: builtins.int
        VERSION_FIELD_NUMBER: builtins.int
        EPOCH_FIELD_NUMBER: builtins.int
        EFFECTIVENAME_FIELD_NUMBER: builtins.int
        WRITESINPROGRESS_FIELD_NUMBER: builtins.int
        READSINPROGRESS_FIELD_NUMBER: builtins.int
        PARTITIONSCACHED_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        STATEREASON_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        MODE_FIELD_NUMBER: builtins.int
        POSITION_FIELD_NUMBER: builtins.int
        PROGRESS_FIELD_NUMBER: builtins.int
        LASTCHECKPOINT_FIELD_NUMBER: builtins.int
        EVENTSPROCESSEDAFTERRESTART_FIELD_NUMBER: builtins.int
        CHECKPOINTSTATUS_FIELD_NUMBER: builtins.int
        BUFFEREDEVENTS_FIELD_NUMBER: builtins.int
        WRITEPENDINGEVENTSBEFORECHECKPOINT_FIELD_NUMBER: builtins.int
        WRITEPENDINGEVENTSAFTERCHECKPOINT_FIELD_NUMBER: builtins.int
        coreProcessingTime: builtins.int
        version: builtins.int
        epoch: builtins.int
        effectiveName: builtins.str
        writesInProgress: builtins.int
        readsInProgress: builtins.int
        partitionsCached: builtins.int
        status: builtins.str
        stateReason: builtins.str
        name: builtins.str
        mode: builtins.str
        position: builtins.str
        progress: builtins.float
        lastCheckpoint: builtins.str
        eventsProcessedAfterRestart: builtins.int
        checkpointStatus: builtins.str
        bufferedEvents: builtins.int
        writePendingEventsBeforeCheckpoint: builtins.int
        writePendingEventsAfterCheckpoint: builtins.int
        def __init__(
            self,
            *,
            coreProcessingTime: builtins.int = ...,
            version: builtins.int = ...,
            epoch: builtins.int = ...,
            effectiveName: builtins.str = ...,
            writesInProgress: builtins.int = ...,
            readsInProgress: builtins.int = ...,
            partitionsCached: builtins.int = ...,
            status: builtins.str = ...,
            stateReason: builtins.str = ...,
            name: builtins.str = ...,
            mode: builtins.str = ...,
            position: builtins.str = ...,
            progress: builtins.float = ...,
            lastCheckpoint: builtins.str = ...,
            eventsProcessedAfterRestart: builtins.int = ...,
            checkpointStatus: builtins.str = ...,
            bufferedEvents: builtins.int = ...,
            writePendingEventsBeforeCheckpoint: builtins.int = ...,
            writePendingEventsAfterCheckpoint: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["bufferedEvents", b"bufferedEvents", "checkpointStatus", b"checkpointStatus", "coreProcessingTime", b"coreProcessingTime", "effectiveName", b"effectiveName", "epoch", b"epoch", "eventsProcessedAfterRestart", b"eventsProcessedAfterRestart", "lastCheckpoint", b"lastCheckpoint", "mode", b"mode", "name", b"name", "partitionsCached", b"partitionsCached", "position", b"position", "progress", b"progress", "readsInProgress", b"readsInProgress", "stateReason", b"stateReason", "status", b"status", "version", b"version", "writePendingEventsAfterCheckpoint", b"writePendingEventsAfterCheckpoint", "writePendingEventsBeforeCheckpoint", b"writePendingEventsBeforeCheckpoint", "writesInProgress", b"writesInProgress"]) -> None: ...

    DETAILS_FIELD_NUMBER: builtins.int
    @property
    def details(self) -> global___StatisticsResp.Details: ...
    def __init__(
        self,
        *,
        details: global___StatisticsResp.Details | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details", b"details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["details", b"details"]) -> None: ...

global___StatisticsResp = StatisticsResp

class StateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        PARTITION_FIELD_NUMBER: builtins.int
        name: builtins.str
        partition: builtins.str
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            partition: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "partition", b"partition"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___StateReq.Options: ...
    def __init__(
        self,
        *,
        options: global___StateReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___StateReq = StateReq

class StateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    @property
    def state(self) -> google.protobuf.struct_pb2.Value: ...
    def __init__(
        self,
        *,
        state: google.protobuf.struct_pb2.Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___StateResp = StateResp

class ResultReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        PARTITION_FIELD_NUMBER: builtins.int
        name: builtins.str
        partition: builtins.str
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            partition: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "partition", b"partition"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___ResultReq.Options: ...
    def __init__(
        self,
        *,
        options: global___ResultReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___ResultReq = ResultReq

class ResultResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> google.protobuf.struct_pb2.Value: ...
    def __init__(
        self,
        *,
        result: google.protobuf.struct_pb2.Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___ResultResp = ResultResp

class ResetReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        WRITE_CHECKPOINT_FIELD_NUMBER: builtins.int
        name: builtins.str
        write_checkpoint: builtins.bool
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            write_checkpoint: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "write_checkpoint", b"write_checkpoint"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___ResetReq.Options: ...
    def __init__(
        self,
        *,
        options: global___ResetReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___ResetReq = ResetReq

class ResetResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ResetResp = ResetResp

class EnableReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        name: builtins.str
        def __init__(
            self,
            *,
            name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___EnableReq.Options: ...
    def __init__(
        self,
        *,
        options: global___EnableReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___EnableReq = EnableReq

class EnableResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EnableResp = EnableResp

class DisableReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Options(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        WRITE_CHECKPOINT_FIELD_NUMBER: builtins.int
        name: builtins.str
        write_checkpoint: builtins.bool
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            write_checkpoint: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "write_checkpoint", b"write_checkpoint"]) -> None: ...

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> global___DisableReq.Options: ...
    def __init__(
        self,
        *,
        options: global___DisableReq.Options | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___DisableReq = DisableReq

class DisableResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DisableResp = DisableResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cshared.proto\x12\x12\x65vent_store.client\x1a\x1bgoogle/protobuf/empty.proto\"\xa9\x01\n\x04UUID\x12\x39\n\nstructured\x18\x01 \x01(\x0b\x32#.event_store.client.UUID.StructuredH\x00\x12\x10\n\x06string\x18\x02 \x01(\tH\x00\x1aK\n\nStructured\x12\x1d\n\x15most_significant_bits\x18\x01 \x01(\x03\x12\x1e\n\x16least_significant_bits\x18\x02 \x01(\x03\x42\x07\n\x05value\"\x07\n\x05\x45mpty\"-\n\x10StreamIdentifier\x12\x13\n\x0bstream_name\x18\x03 \x01(\x0cJ\x04\x08\x01\x10\x03\"F\n\x11\x41llStreamPosition\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\"\xf7\x02\n\x14WrongExpectedVersion\x12!\n\x17\x63urrent_stream_revision\x18\x01 \x01(\x04H\x00\x12\x33\n\x11\x63urrent_no_stream\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\"\n\x18\x65xpected_stream_position\x18\x03 \x01(\x04H\x01\x12.\n\x0c\x65xpected_any\x18\x04 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x38\n\x16\x65xpected_stream_exists\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x34\n\x12\x65xpected_no_stream\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x42 \n\x1e\x63urrent_stream_revision_optionB!\n\x1f\x65xpected_stream_position_option\"\x0e\n\x0c\x41\x63\x63\x65ssDenied\"P\n\rStreamDeleted\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\"\t\n\x07Timeout\"\t\n\x07Unknown\"\x14\n\x12InvalidTransaction\"2\n\x19MaximumAppendSizeExceeded\x12\x15\n\rmaxAppendSize\x18\x01 \x01(\r\"\x1d\n\nBadRequest\x12\x0f\n\x07message\x18\x01 \x01(\tB&\n$com.eventstore.dbclient.proto.sharedb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.eventstore.dbclient.proto.shared'
  _UUID._serialized_start=66
  _UUID._serialized_end=235
  _UUID_STRUCTURED._serialized_start=151
  _UUID_STRUCTURED._serialized_end=226
  _EMPTY._serialized_start=237
  _EMPTY._serialized_end=244
  _STREAMIDENTIFIER._serialized_start=246
  _STREAMIDENTIFIER._serialized_end=291
  _ALLSTREAMPOSITION._serialized_start=293
  _ALLSTREAMPOSITION._serialized_end=363
  _WRONGEXPECTEDVERSION._serialized_start=366
  _WRONGEXPECTEDVERSION._serialized_end=741
  _ACCESSDENIED._serialized_start=743
  _ACCESSDENIED._serialized_end=757
  _STREAMDELETED._serialized_start=759
  _STREAMDELETED._serialized_end=839
  _TIMEOUT._serialized_start=841
  _TIMEOUT._serialized_end=850
  _UNKNOWN._serialized_start=852
  _UNKNOWN._serialized_end=861
  _INVALIDTRANSACTION._serialized_start=863
  _INVALIDTRANSACTION._serialized_end=883
  _MAXIMUMAPPENDSIZEEXCEEDED._serialized_start=885
  _MAXIMUMAPPENDSIZEEXCEEDED._serialized_end=935
  _BADREQUEST._serialized_start=937
  _BADREQUEST._serialized_end=966
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

import enum
import json
import logging
import uuid
from dataclasses import dataclass, field
from typing import Mapping, Optional, Type, TypeVar, Union

from esdb.generated.shared_pb2 import UUID
from esdb.generated.streams_pb2 import (
    AppendReq,
    AppendResp,
    BatchAppendReq,
    BatchAppendResp,
    DeleteResp,
    ReadResp,
    TombstoneResp,
)

logger = logging.getLogger(__name__)


@enum.unique
class StreamState(enum.Enum):
    ANY = "any"
    NO_STREAM = "no_stream"
    STREAM_EXISTS = "stream_exists"


@dataclass
class AppendResult:
    current_revision: int
    commit_position: int
    prepare_position: int

    @staticmethod
    def from_response(response: AppendResp) -> AppendResult:
        return AppendResult(
            current_revision=response.success.current_revision,
            commit_position=response.success.position.commit_position,
            prepare_position=response.success.position.prepare_position,
        )


@dataclass
class DeleteResult:
    commit_position: int
    prepare_position: int

    @staticmethod
    def from_response(response: DeleteResp) -> DeleteResult:
        return DeleteResult(
            commit_position=response.position.commit_position,
            prepare_position=response.position.prepare_position,
        )


@dataclass
class TombstoneResult:
    commit_position: int
    prepare_position: int

    @staticmethod
    def from_response(response: TombstoneResp) -> TombstoneResult:
        return TombstoneResult(
            commit_position=response.position.commit_position,
            prepare_position=response.position.prepare_position,
        )


@enum.unique
class ContentType(enum.Enum):
    OCTET_STREAM = "application/octet-stream"
    JSON = "application/json"


@dataclass
class ReadEvent:
    id: str
    stream_name: str
    prepare_position: int
    commit_position: int
    metadata: Mapping[str, str]
    event_type: str
    custom_metadata: Optional[dict]
    data: Union[dict, bytes]

    @staticmethod
    def from_response(response: ReadResp) -> ReadEvent:
        return ReadEvent(
            id=response.event.event.id.string,
            stream_name=response.event.event.stream_identifier.stream_name.decode(),
            metadata=response.event.event.metadata,
            custom_metadata=json.loads(response.event.event.custom_metadata)
            if response.event.event.custom_metadata
            else None,
            data=json.loads(response.event.event.data)
            if response.event.event.metadata["content-type"] == ContentType.JSON.value
            else response.event.event.data,
            prepare_position=response.event.commit_position,
            commit_position=response.event.commit_position,
            event_type=response.event.event.metadata["type"],
        )


@dataclass
class SubscriptionConfirmed:
    subscription_id: str


@dataclass
class Checkpoint:
    commit_position: int
    prepare_position: int


ProposedMessageType = TypeVar("ProposedMessageType", BatchAppendReq.ProposedMessage, AppendReq.ProposedMessage)


@dataclass
class Message:
    event_type: str
    data: Union[bytes, dict]
    id: uuid.UUID = field(default_factory=uuid.uuid4)
    custom_metadata: Optional[dict] = None

    def to_protobuf(self, message_type: Type[ProposedMessageType]) -> ProposedMessageType:
        assert isinstance(self.data, (bytes, dict))
        return message_type(
            id=UUID(string=str(self.id)),
            metadata={
                "type": self.event_type,
                "content-type": ContentType.OCTET_STREAM.value
                if isinstance(self.data, bytes)
                else ContentType.JSON.value,
            },
            custom_metadata=json.dumps(self.custom_metadata).encode() if self.custom_metadata else b"",
            data=json.dumps(self.data).encode() if isinstance(self.data, dict) else self.data,
        )


@dataclass
class BatchAppendResult:
    correlation_id: str
    current_revision: int
    commit_position: int
    prepare_position: int

    @staticmethod
    def from_response(response: BatchAppendResp) -> BatchAppendResult:
        return BatchAppendResult(
            correlation_id=response.correlation_id,
            current_revision=response.success.current_revision,
            commit_position=response.success.position.commit_position,
            prepare_position=response.success.position.prepare_position,
        )



from esdb.subscriptions.subscriptions import PersistentSubscriptions
from esdb.subscriptions.types import Event, NackAction, SubscriptionSettings

__all__ = ["NackAction", "SubscriptionSettings", "PersistentSubscriptions", "Event"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: operations.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import shared_pb2 as shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10operations.proto\x12\x1d\x65vent_store.client.operations\x1a\x0cshared.proto\"\x97\x01\n\x10StartScavengeReq\x12H\n\x07options\x18\x01 \x01(\x0b\x32\x37.event_store.client.operations.StartScavengeReq.Options\x1a\x39\n\x07Options\x12\x14\n\x0cthread_count\x18\x01 \x01(\x05\x12\x18\n\x10start_from_chunk\x18\x02 \x01(\x05\"z\n\x0fStopScavengeReq\x12G\n\x07options\x18\x01 \x01(\x0b\x32\x36.event_store.client.operations.StopScavengeReq.Options\x1a\x1e\n\x07Options\x12\x13\n\x0bscavenge_id\x18\x01 \x01(\t\"\xb4\x01\n\x0cScavengeResp\x12\x13\n\x0bscavenge_id\x18\x01 \x01(\t\x12S\n\x0fscavenge_result\x18\x02 \x01(\x0e\x32:.event_store.client.operations.ScavengeResp.ScavengeResult\":\n\x0eScavengeResult\x12\x0b\n\x07Started\x10\x00\x12\x0e\n\nInProgress\x10\x01\x12\x0b\n\x07Stopped\x10\x02\"&\n\x12SetNodePriorityReq\x12\x10\n\x08priority\x18\x01 \x01(\x05\x32\xed\x04\n\nOperations\x12m\n\rStartScavenge\x12/.event_store.client.operations.StartScavengeReq\x1a+.event_store.client.operations.ScavengeResp\x12k\n\x0cStopScavenge\x12..event_store.client.operations.StopScavengeReq\x1a+.event_store.client.operations.ScavengeResp\x12@\n\x08Shutdown\x12\x19.event_store.client.Empty\x1a\x19.event_store.client.Empty\x12\x44\n\x0cMergeIndexes\x12\x19.event_store.client.Empty\x1a\x19.event_store.client.Empty\x12\x42\n\nResignNode\x12\x19.event_store.client.Empty\x1a\x19.event_store.client.Empty\x12_\n\x0fSetNodePriority\x12\x31.event_store.client.operations.SetNodePriorityReq\x1a\x19.event_store.client.Empty\x12V\n\x1eRestartPersistentSubscriptions\x12\x19.event_store.client.Empty\x1a\x19.event_store.client.EmptyB*\n(com.eventstore.dbclient.proto.operationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'operations_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.eventstore.dbclient.proto.operations'
  _STARTSCAVENGEREQ._serialized_start=66
  _STARTSCAVENGEREQ._serialized_end=217
  _STARTSCAVENGEREQ_OPTIONS._serialized_start=160
  _STARTSCAVENGEREQ_OPTIONS._serialized_end=217
  _STOPSCAVENGEREQ._serialized_start=219
  _STOPSCAVENGEREQ._serialized_end=341
  _STOPSCAVENGEREQ_OPTIONS._serialized_start=311
  _STOPSCAVENGEREQ_OPTIONS._serialized_end=341
  _SCAVENGERESP._serialized_start=344
  _SCAVENGERESP._serialized_end=524
  _SCAVENGERESP_SCAVENGERESULT._serialized_start=466
  _SCAVENGERESP_SCAVENGERESULT._serialized_end=524
  _SETNODEPRIORITYREQ._serialized_start=526
  _SETNODEPRIORITYREQ._serialized_end=564
  _OPERATIONS._serialized_start=567
  _OPERATIONS._serialized_end=1188
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UUID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Structured(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MOST_SIGNIFICANT_BITS_FIELD_NUMBER: builtins.int
        LEAST_SIGNIFICANT_BITS_FIELD_NUMBER: builtins.int
        most_significant_bits: builtins.int
        least_significant_bits: builtins.int
        def __init__(
            self,
            *,
            most_significant_bits: builtins.int = ...,
            least_significant_bits: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["least_significant_bits", b"least_significant_bits", "most_significant_bits", b"most_significant_bits"]) -> None: ...

    STRUCTURED_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    @property
    def structured(self) -> global___UUID.Structured: ...
    string: builtins.str
    def __init__(
        self,
        *,
        structured: global___UUID.Structured | None = ...,
        string: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["string", b"string", "structured", b"structured", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["string", b"string", "structured", b"structured", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value", b"value"]) -> typing_extensions.Literal["structured", "string"] | None: ...

global___UUID = UUID

class Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty

class StreamIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_NAME_FIELD_NUMBER: builtins.int
    stream_name: builtins.bytes
    def __init__(
        self,
        *,
        stream_name: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stream_name", b"stream_name"]) -> None: ...

global___StreamIdentifier = StreamIdentifier

class AllStreamPosition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMIT_POSITION_FIELD_NUMBER: builtins.int
    PREPARE_POSITION_FIELD_NUMBER: builtins.int
    commit_position: builtins.int
    prepare_position: builtins.int
    def __init__(
        self,
        *,
        commit_position: builtins.int = ...,
        prepare_position: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_position", b"commit_position", "prepare_position", b"prepare_position"]) -> None: ...

global___AllStreamPosition = AllStreamPosition

class WrongExpectedVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_STREAM_REVISION_FIELD_NUMBER: builtins.int
    CURRENT_NO_STREAM_FIELD_NUMBER: builtins.int
    EXPECTED_STREAM_POSITION_FIELD_NUMBER: builtins.int
    EXPECTED_ANY_FIELD_NUMBER: builtins.int
    EXPECTED_STREAM_EXISTS_FIELD_NUMBER: builtins.int
    EXPECTED_NO_STREAM_FIELD_NUMBER: builtins.int
    current_stream_revision: builtins.int
    @property
    def current_no_stream(self) -> google.protobuf.empty_pb2.Empty: ...
    expected_stream_position: builtins.int
    @property
    def expected_any(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def expected_stream_exists(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def expected_no_stream(self) -> google.protobuf.empty_pb2.Empty: ...
    def __init__(
        self,
        *,
        current_stream_revision: builtins.int = ...,
        current_no_stream: google.protobuf.empty_pb2.Empty | None = ...,
        expected_stream_position: builtins.int = ...,
        expected_any: google.protobuf.empty_pb2.Empty | None = ...,
        expected_stream_exists: google.protobuf.empty_pb2.Empty | None = ...,
        expected_no_stream: google.protobuf.empty_pb2.Empty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current_no_stream", b"current_no_stream", "current_stream_revision", b"current_stream_revision", "current_stream_revision_option", b"current_stream_revision_option", "expected_any", b"expected_any", "expected_no_stream", b"expected_no_stream", "expected_stream_exists", b"expected_stream_exists", "expected_stream_position", b"expected_stream_position", "expected_stream_position_option", b"expected_stream_position_option"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_no_stream", b"current_no_stream", "current_stream_revision", b"current_stream_revision", "current_stream_revision_option", b"current_stream_revision_option", "expected_any", b"expected_any", "expected_no_stream", b"expected_no_stream", "expected_stream_exists", b"expected_stream_exists", "expected_stream_position", b"expected_stream_position", "expected_stream_position_option", b"expected_stream_position_option"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["current_stream_revision_option", b"current_stream_revision_option"]) -> typing_extensions.Literal["current_stream_revision", "current_no_stream"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["expected_stream_position_option", b"expected_stream_position_option"]) -> typing_extensions.Literal["expected_stream_position", "expected_any", "expected_stream_exists", "expected_no_stream"] | None: ...

global___WrongExpectedVersion = WrongExpectedVersion

class AccessDenied(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AccessDenied = AccessDenied

class StreamDeleted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def stream_identifier(self) -> global___StreamIdentifier: ...
    def __init__(
        self,
        *,
        stream_identifier: global___StreamIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stream_identifier", b"stream_identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["stream_identifier", b"stream_identifier"]) -> None: ...

global___StreamDeleted = StreamDeleted

class Timeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Timeout = Timeout

class Unknown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Unknown = Unknown

class InvalidTransaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InvalidTransaction = InvalidTransaction

class MaximumAppendSizeExceeded(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXAPPENDSIZE_FIELD_NUMBER: builtins.int
    maxAppendSize: builtins.int
    def __init__(
        self,
        *,
        maxAppendSize: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["maxAppendSize", b"maxAppendSize"]) -> None: ...

global___MaximumAppendSizeExceeded = MaximumAppendSizeExceeded

class BadRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___BadRequest = BadRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: persistent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import shared_pb2 as shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10persistent.proto\x12+event_store.client.persistent_subscriptions\x1a\x0cshared.proto\"\x99\x07\n\x07ReadReq\x12O\n\x07options\x18\x01 \x01(\x0b\x32<.event_store.client.persistent_subscriptions.ReadReq.OptionsH\x00\x12G\n\x03\x61\x63k\x18\x02 \x01(\x0b\x32\x38.event_store.client.persistent_subscriptions.ReadReq.AckH\x00\x12I\n\x04nack\x18\x03 \x01(\x0b\x32\x39.event_store.client.persistent_subscriptions.ReadReq.NackH\x00\x1a\x85\x03\n\x07Options\x12\x41\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierH\x00\x12(\n\x03\x61ll\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x13\n\x0b\x62uffer_size\x18\x03 \x01(\x05\x12\\\n\x0buuid_option\x18\x04 \x01(\x0b\x32G.event_store.client.persistent_subscriptions.ReadReq.Options.UUIDOption\x1au\n\nUUIDOption\x12/\n\nstructured\x18\x01 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12+\n\x06string\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\t\n\x07\x63ontentB\x0f\n\rstream_option\x1a\x38\n\x03\x41\x63k\x12\n\n\x02id\x18\x01 \x01(\x0c\x12%\n\x03ids\x18\x02 \x03(\x0b\x32\x18.event_store.client.UUID\x1a\xdb\x01\n\x04Nack\x12\n\n\x02id\x18\x01 \x01(\x0c\x12%\n\x03ids\x18\x02 \x03(\x0b\x32\x18.event_store.client.UUID\x12P\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32@.event_store.client.persistent_subscriptions.ReadReq.Nack.Action\x12\x0e\n\x06reason\x18\x04 \x01(\t\">\n\x06\x41\x63tion\x12\x0b\n\x07Unknown\x10\x00\x12\x08\n\x04Park\x10\x01\x12\t\n\x05Retry\x10\x02\x12\x08\n\x04Skip\x10\x03\x12\x08\n\x04Stop\x10\x04\x42\t\n\x07\x63ontent\"\x94\x08\n\x08ReadResp\x12P\n\x05\x65vent\x18\x01 \x01(\x0b\x32?.event_store.client.persistent_subscriptions.ReadResp.ReadEventH\x00\x12s\n\x19subscription_confirmation\x18\x02 \x01(\x0b\x32N.event_store.client.persistent_subscriptions.ReadResp.SubscriptionConfirmationH\x00\x1a\x80\x06\n\tReadEvent\x12\\\n\x05\x65vent\x18\x01 \x01(\x0b\x32M.event_store.client.persistent_subscriptions.ReadResp.ReadEvent.RecordedEvent\x12[\n\x04link\x18\x02 \x01(\x0b\x32M.event_store.client.persistent_subscriptions.ReadResp.ReadEvent.RecordedEvent\x12\x19\n\x0f\x63ommit_position\x18\x03 \x01(\x04H\x00\x12\x30\n\x0bno_position\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x15\n\x0bretry_count\x18\x05 \x01(\x05H\x01\x12\x33\n\x0eno_retry_count\x18\x06 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x1a\x89\x03\n\rRecordedEvent\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12?\n\x11stream_identifier\x18\x02 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x17\n\x0fstream_revision\x18\x03 \x01(\x04\x12\x18\n\x10prepare_position\x18\x04 \x01(\x04\x12\x17\n\x0f\x63ommit_position\x18\x05 \x01(\x04\x12m\n\x08metadata\x18\x06 \x03(\x0b\x32[.event_store.client.persistent_subscriptions.ReadResp.ReadEvent.RecordedEvent.MetadataEntry\x12\x17\n\x0f\x63ustom_metadata\x18\x07 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\x0c\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08positionB\x07\n\x05\x63ount\x1a\x33\n\x18SubscriptionConfirmation\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\tB\t\n\x07\x63ontent\"\xf6\x10\n\tCreateReq\x12O\n\x07options\x18\x01 \x01(\x0b\x32>.event_store.client.persistent_subscriptions.CreateReq.Options\x1a\xf0\x02\n\x07Options\x12V\n\x06stream\x18\x04 \x01(\x0b\x32\x44.event_store.client.persistent_subscriptions.CreateReq.StreamOptionsH\x00\x12P\n\x03\x61ll\x18\x05 \x01(\x0b\x32\x41.event_store.client.persistent_subscriptions.CreateReq.AllOptionsH\x00\x12\x43\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierB\x02\x18\x01\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12Q\n\x08settings\x18\x03 \x01(\x0b\x32?.event_store.client.persistent_subscriptions.CreateReq.SettingsB\x0f\n\rstream_option\x1a\xcd\x01\n\rStreamOptions\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02 \x01(\x04H\x00\x12*\n\x05start\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x11\n\x0frevision_option\x1a\x88\x06\n\nAllOptions\x12S\n\x08position\x18\x01 \x01(\x0b\x32?.event_store.client.persistent_subscriptions.CreateReq.PositionH\x00\x12*\n\x05start\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x61\n\x06\x66ilter\x18\x04 \x01(\x0b\x32O.event_store.client.persistent_subscriptions.CreateReq.AllOptions.FilterOptionsH\x01\x12.\n\tno_filter\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x1a\x9c\x03\n\rFilterOptions\x12w\n\x11stream_identifier\x18\x01 \x01(\x0b\x32Z.event_store.client.persistent_subscriptions.CreateReq.AllOptions.FilterOptions.ExpressionH\x00\x12p\n\nevent_type\x18\x02 \x01(\x0b\x32Z.event_store.client.persistent_subscriptions.CreateReq.AllOptions.FilterOptions.ExpressionH\x00\x12\r\n\x03max\x18\x03 \x01(\rH\x01\x12*\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x12$\n\x1c\x63heckpointIntervalMultiplier\x18\x05 \x01(\r\x1a+\n\nExpression\x12\r\n\x05regex\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x03(\tB\x08\n\x06\x66ilterB\x08\n\x06windowB\x0c\n\nall_optionB\x0f\n\rfilter_option\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x1a\xc4\x04\n\x08Settings\x12\x15\n\rresolve_links\x18\x01 \x01(\x08\x12\x14\n\x08revision\x18\x02 \x01(\x04\x42\x02\x18\x01\x12\x18\n\x10\x65xtra_statistics\x18\x03 \x01(\x08\x12\x17\n\x0fmax_retry_count\x18\x05 \x01(\x05\x12\x1c\n\x14min_checkpoint_count\x18\x07 \x01(\x05\x12\x1c\n\x14max_checkpoint_count\x18\x08 \x01(\x05\x12\x1c\n\x14max_subscriber_count\x18\t \x01(\x05\x12\x18\n\x10live_buffer_size\x18\n \x01(\x05\x12\x17\n\x0fread_batch_size\x18\x0b \x01(\x05\x12\x1b\n\x13history_buffer_size\x18\x0c \x01(\x05\x12l\n\x17named_consumer_strategy\x18\r \x01(\x0e\x32G.event_store.client.persistent_subscriptions.CreateReq.ConsumerStrategyB\x02\x18\x01\x12\x1f\n\x15message_timeout_ticks\x18\x04 \x01(\x03H\x00\x12\x1c\n\x12message_timeout_ms\x18\x0e \x01(\x05H\x00\x12 \n\x16\x63heckpoint_after_ticks\x18\x06 \x01(\x03H\x01\x12\x1d\n\x13\x63heckpoint_after_ms\x18\x0f \x01(\x05H\x01\x12\x19\n\x11\x63onsumer_strategy\x18\x10 \x01(\tB\x11\n\x0fmessage_timeoutB\x12\n\x10\x63heckpoint_after\"D\n\x10\x43onsumerStrategy\x12\x14\n\x10\x44ispatchToSingle\x10\x00\x12\x0e\n\nRoundRobin\x10\x01\x12\n\n\x06Pinned\x10\x02\"\x0c\n\nCreateResp\"\x94\x0c\n\tUpdateReq\x12O\n\x07options\x18\x01 \x01(\x0b\x32>.event_store.client.persistent_subscriptions.UpdateReq.Options\x1a\xf0\x02\n\x07Options\x12V\n\x06stream\x18\x04 \x01(\x0b\x32\x44.event_store.client.persistent_subscriptions.UpdateReq.StreamOptionsH\x00\x12P\n\x03\x61ll\x18\x05 \x01(\x0b\x32\x41.event_store.client.persistent_subscriptions.UpdateReq.AllOptionsH\x00\x12\x43\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierB\x02\x18\x01\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12Q\n\x08settings\x18\x03 \x01(\x0b\x32?.event_store.client.persistent_subscriptions.UpdateReq.SettingsB\x0f\n\rstream_option\x1a\xcd\x01\n\rStreamOptions\x12?\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifier\x12\x12\n\x08revision\x18\x02 \x01(\x04H\x00\x12*\n\x05start\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x11\n\x0frevision_option\x1a\xc5\x01\n\nAllOptions\x12S\n\x08position\x18\x01 \x01(\x0b\x32?.event_store.client.persistent_subscriptions.UpdateReq.PositionH\x00\x12*\n\x05start\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12(\n\x03\x65nd\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x0c\n\nall_option\x1a=\n\x08Position\x12\x17\n\x0f\x63ommit_position\x18\x01 \x01(\x04\x12\x18\n\x10prepare_position\x18\x02 \x01(\x04\x1a\xa5\x04\n\x08Settings\x12\x15\n\rresolve_links\x18\x01 \x01(\x08\x12\x14\n\x08revision\x18\x02 \x01(\x04\x42\x02\x18\x01\x12\x18\n\x10\x65xtra_statistics\x18\x03 \x01(\x08\x12\x17\n\x0fmax_retry_count\x18\x05 \x01(\x05\x12\x1c\n\x14min_checkpoint_count\x18\x07 \x01(\x05\x12\x1c\n\x14max_checkpoint_count\x18\x08 \x01(\x05\x12\x1c\n\x14max_subscriber_count\x18\t \x01(\x05\x12\x18\n\x10live_buffer_size\x18\n \x01(\x05\x12\x17\n\x0fread_batch_size\x18\x0b \x01(\x05\x12\x1b\n\x13history_buffer_size\x18\x0c \x01(\x05\x12h\n\x17named_consumer_strategy\x18\r \x01(\x0e\x32G.event_store.client.persistent_subscriptions.UpdateReq.ConsumerStrategy\x12\x1f\n\x15message_timeout_ticks\x18\x04 \x01(\x03H\x00\x12\x1c\n\x12message_timeout_ms\x18\x0e \x01(\x05H\x00\x12 \n\x16\x63heckpoint_after_ticks\x18\x06 \x01(\x03H\x01\x12\x1d\n\x13\x63heckpoint_after_ms\x18\x0f \x01(\x05H\x01\x42\x11\n\x0fmessage_timeoutB\x12\n\x10\x63heckpoint_after\"D\n\x10\x43onsumerStrategy\x12\x14\n\x10\x44ispatchToSingle\x10\x00\x12\x0e\n\nRoundRobin\x10\x01\x12\n\n\x06Pinned\x10\x02\"\x0c\n\nUpdateResp\"\xfa\x01\n\tDeleteReq\x12O\n\x07options\x18\x01 \x01(\x0b\x32>.event_store.client.persistent_subscriptions.DeleteReq.Options\x1a\x9b\x01\n\x07Options\x12\x41\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierH\x00\x12(\n\x03\x61ll\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x12\n\ngroup_name\x18\x02 \x01(\tB\x0f\n\rstream_option\"\x0c\n\nDeleteResp\"\xfc\x01\n\nGetInfoReq\x12P\n\x07options\x18\x01 \x01(\x0b\x32?.event_store.client.persistent_subscriptions.GetInfoReq.Options\x1a\x9b\x01\n\x07Options\x12\x41\n\x11stream_identifier\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierH\x00\x12(\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x12\n\ngroup_name\x18\x03 \x01(\tB\x0f\n\rstream_option\"g\n\x0bGetInfoResp\x12X\n\x11subscription_info\x18\x01 \x01(\x0b\x32=.event_store.client.persistent_subscriptions.SubscriptionInfo\"\xf0\t\n\x10SubscriptionInfo\x12\x14\n\x0c\x65vent_source\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x61\n\x0b\x63onnections\x18\x04 \x03(\x0b\x32L.event_store.client.persistent_subscriptions.SubscriptionInfo.ConnectionInfo\x12\x1a\n\x12\x61verage_per_second\x18\x05 \x01(\x05\x12\x13\n\x0btotal_items\x18\x06 \x01(\x03\x12$\n\x1c\x63ount_since_last_measurement\x18\x07 \x01(\x03\x12(\n last_checkpointed_event_position\x18\x08 \x01(\t\x12!\n\x19last_known_event_position\x18\t \x01(\t\x12\x18\n\x10resolve_link_tos\x18\n \x01(\x08\x12\x12\n\nstart_from\x18\x0b \x01(\t\x12$\n\x1cmessage_timeout_milliseconds\x18\x0c \x01(\x05\x12\x18\n\x10\x65xtra_statistics\x18\r \x01(\x08\x12\x17\n\x0fmax_retry_count\x18\x0e \x01(\x05\x12\x18\n\x10live_buffer_size\x18\x0f \x01(\x05\x12\x13\n\x0b\x62uffer_size\x18\x10 \x01(\x05\x12\x17\n\x0fread_batch_size\x18\x11 \x01(\x05\x12&\n\x1e\x63heck_point_after_milliseconds\x18\x12 \x01(\x05\x12\x1d\n\x15min_check_point_count\x18\x13 \x01(\x05\x12\x1d\n\x15max_check_point_count\x18\x14 \x01(\x05\x12\x19\n\x11read_buffer_count\x18\x15 \x01(\x05\x12\x19\n\x11live_buffer_count\x18\x16 \x01(\x03\x12\x1a\n\x12retry_buffer_count\x18\x17 \x01(\x05\x12 \n\x18total_in_flight_messages\x18\x18 \x01(\x05\x12\"\n\x1aoutstanding_messages_count\x18\x19 \x01(\x05\x12\x1f\n\x17named_consumer_strategy\x18\x1a \x01(\t\x12\x1c\n\x14max_subscriber_count\x18\x1b \x01(\x05\x12\x1c\n\x14parked_message_count\x18\x1c \x01(\x03\x1a\xc5\x02\n\x0e\x43onnectionInfo\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12 \n\x18\x61verage_items_per_second\x18\x03 \x01(\x05\x12\x13\n\x0btotal_items\x18\x04 \x01(\x03\x12$\n\x1c\x63ount_since_last_measurement\x18\x05 \x01(\x03\x12h\n\x15observed_measurements\x18\x06 \x03(\x0b\x32I.event_store.client.persistent_subscriptions.SubscriptionInfo.Measurement\x12\x17\n\x0f\x61vailable_slots\x18\x07 \x01(\x05\x12\x1a\n\x12in_flight_messages\x18\x08 \x01(\x05\x12\x17\n\x0f\x63onnection_name\x18\t \x01(\t\x1a)\n\x0bMeasurement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\"\xda\x02\n\x0fReplayParkedReq\x12U\n\x07options\x18\x01 \x01(\x0b\x32\x44.event_store.client.persistent_subscriptions.ReplayParkedReq.Options\x1a\xef\x01\n\x07Options\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\x41\n\x11stream_identifier\x18\x02 \x01(\x0b\x32$.event_store.client.StreamIdentifierH\x00\x12(\n\x03\x61ll\x18\x03 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\x11\n\x07stop_at\x18\x04 \x01(\x03H\x01\x12-\n\x08no_limit\x18\x05 \x01(\x0b\x32\x19.event_store.client.EmptyH\x01\x42\x0f\n\rstream_optionB\x10\n\x0estop_at_option\"\x12\n\x10ReplayParkedResp\"\x92\x03\n\x07ListReq\x12M\n\x07options\x18\x01 \x01(\x0b\x32<.event_store.client.persistent_subscriptions.ListReq.Options\x1a\xb3\x01\n\x07Options\x12;\n\x16list_all_subscriptions\x18\x01 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x12\\\n\x0flist_for_stream\x18\x02 \x01(\x0b\x32\x41.event_store.client.persistent_subscriptions.ListReq.StreamOptionH\x00\x42\r\n\x0blist_option\x1a\x81\x01\n\x0cStreamOption\x12\x36\n\x06stream\x18\x01 \x01(\x0b\x32$.event_store.client.StreamIdentifierH\x00\x12(\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x19.event_store.client.EmptyH\x00\x42\x0f\n\rstream_option\"`\n\x08ListResp\x12T\n\rsubscriptions\x18\x01 \x03(\x0b\x32=.event_store.client.persistent_subscriptions.SubscriptionInfo2\xce\x07\n\x17PersistentSubscriptions\x12y\n\x06\x43reate\x12\x36.event_store.client.persistent_subscriptions.CreateReq\x1a\x37.event_store.client.persistent_subscriptions.CreateResp\x12y\n\x06Update\x12\x36.event_store.client.persistent_subscriptions.UpdateReq\x1a\x37.event_store.client.persistent_subscriptions.UpdateResp\x12y\n\x06\x44\x65lete\x12\x36.event_store.client.persistent_subscriptions.DeleteReq\x1a\x37.event_store.client.persistent_subscriptions.DeleteResp\x12w\n\x04Read\x12\x34.event_store.client.persistent_subscriptions.ReadReq\x1a\x35.event_store.client.persistent_subscriptions.ReadResp(\x01\x30\x01\x12|\n\x07GetInfo\x12\x37.event_store.client.persistent_subscriptions.GetInfoReq\x1a\x38.event_store.client.persistent_subscriptions.GetInfoResp\x12\x8b\x01\n\x0cReplayParked\x12<.event_store.client.persistent_subscriptions.ReplayParkedReq\x1a=.event_store.client.persistent_subscriptions.ReplayParkedResp\x12s\n\x04List\x12\x34.event_store.client.persistent_subscriptions.ListReq\x1a\x35.event_store.client.persistent_subscriptions.ListResp\x12H\n\x10RestartSubsystem\x12\x19.event_store.client.Empty\x1a\x19.event_store.client.EmptyB7\n5com.eventstore.dbclient.proto.persistentsubscriptionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'persistent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5com.eventstore.dbclient.proto.persistentsubscriptions'
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._options = None
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_options = b'8\001'
  _CREATEREQ_OPTIONS.fields_by_name['stream_identifier']._options = None
  _CREATEREQ_OPTIONS.fields_by_name['stream_identifier']._serialized_options = b'\030\001'
  _CREATEREQ_SETTINGS.fields_by_name['revision']._options = None
  _CREATEREQ_SETTINGS.fields_by_name['revision']._serialized_options = b'\030\001'
  _CREATEREQ_SETTINGS.fields_by_name['named_consumer_strategy']._options = None
  _CREATEREQ_SETTINGS.fields_by_name['named_consumer_strategy']._serialized_options = b'\030\001'
  _UPDATEREQ_OPTIONS.fields_by_name['stream_identifier']._options = None
  _UPDATEREQ_OPTIONS.fields_by_name['stream_identifier']._serialized_options = b'\030\001'
  _UPDATEREQ_SETTINGS.fields_by_name['revision']._options = None
  _UPDATEREQ_SETTINGS.fields_by_name['revision']._serialized_options = b'\030\001'
  _READREQ._serialized_start=80
  _READREQ._serialized_end=1001
  _READREQ_OPTIONS._serialized_start=321
  _READREQ_OPTIONS._serialized_end=710
  _READREQ_OPTIONS_UUIDOPTION._serialized_start=576
  _READREQ_OPTIONS_UUIDOPTION._serialized_end=693
  _READREQ_ACK._serialized_start=712
  _READREQ_ACK._serialized_end=768
  _READREQ_NACK._serialized_start=771
  _READREQ_NACK._serialized_end=990
  _READREQ_NACK_ACTION._serialized_start=928
  _READREQ_NACK_ACTION._serialized_end=990
  _READRESP._serialized_start=1004
  _READRESP._serialized_end=2048
  _READRESP_READEVENT._serialized_start=1216
  _READRESP_READEVENT._serialized_end=1984
  _READRESP_READEVENT_RECORDEDEVENT._serialized_start=1570
  _READRESP_READEVENT_RECORDEDEVENT._serialized_end=1963
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_start=1916
  _READRESP_READEVENT_RECORDEDEVENT_METADATAENTRY._serialized_end=1963
  _READRESP_SUBSCRIPTIONCONFIRMATION._serialized_start=1986
  _READRESP_SUBSCRIPTIONCONFIRMATION._serialized_end=2037
  _CREATEREQ._serialized_start=2051
  _CREATEREQ._serialized_end=4217
  _CREATEREQ_OPTIONS._serialized_start=2146
  _CREATEREQ_OPTIONS._serialized_end=2514
  _CREATEREQ_STREAMOPTIONS._serialized_start=2517
  _CREATEREQ_STREAMOPTIONS._serialized_end=2722
  _CREATEREQ_ALLOPTIONS._serialized_start=2725
  _CREATEREQ_ALLOPTIONS._serialized_end=3501
  _CREATEREQ_ALLOPTIONS_FILTEROPTIONS._serialized_start=3058
  _CREATEREQ_ALLOPTIONS_FILTEROPTIONS._serialized_end=3470
  _CREATEREQ_ALLOPTIONS_FILTEROPTIONS_EXPRESSION._serialized_start=3407
  _CREATEREQ_ALLOPTIONS_FILTEROPTIONS_EXPRESSION._serialized_end=3450
  _CREATEREQ_POSITION._serialized_start=3503
  _CREATEREQ_POSITION._serialized_end=3564
  _CREATEREQ_SETTINGS._serialized_start=3567
  _CREATEREQ_SETTINGS._serialized_end=4147
  _CREATEREQ_CONSUMERSTRATEGY._serialized_start=4149
  _CREATEREQ_CONSUMERSTRATEGY._serialized_end=4217
  _CREATERESP._serialized_start=4219
  _CREATERESP._serialized_end=4231
  _UPDATEREQ._serialized_start=4234
  _UPDATEREQ._serialized_end=5790
  _UPDATEREQ_OPTIONS._serialized_start=4329
  _UPDATEREQ_OPTIONS._serialized_end=4697
  _UPDATEREQ_STREAMOPTIONS._serialized_start=2517
  _UPDATEREQ_STREAMOPTIONS._serialized_end=2722
  _UPDATEREQ_ALLOPTIONS._serialized_start=4908
  _UPDATEREQ_ALLOPTIONS._serialized_end=5105
  _UPDATEREQ_POSITION._serialized_start=3503
  _UPDATEREQ_POSITION._serialized_end=3564
  _UPDATEREQ_SETTINGS._serialized_start=5171
  _UPDATEREQ_SETTINGS._serialized_end=5720
  _UPDATEREQ_CONSUMERSTRATEGY._serialized_start=4149
  _UPDATEREQ_CONSUMERSTRATEGY._serialized_end=4217
  _UPDATERESP._serialized_start=5792
  _UPDATERESP._serialized_end=5804
  _DELETEREQ._serialized_start=5807
  _DELETEREQ._serialized_end=6057
  _DELETEREQ_OPTIONS._serialized_start=5902
  _DELETEREQ_OPTIONS._serialized_end=6057
  _DELETERESP._serialized_start=6059
  _DELETERESP._serialized_end=6071
  _GETINFOREQ._serialized_start=6074
  _GETINFOREQ._serialized_end=6326
  _GETINFOREQ_OPTIONS._serialized_start=6171
  _GETINFOREQ_OPTIONS._serialized_end=6326
  _GETINFORESP._serialized_start=6328
  _GETINFORESP._serialized_end=6431
  _SUBSCRIPTIONINFO._serialized_start=6434
  _SUBSCRIPTIONINFO._serialized_end=7698
  _SUBSCRIPTIONINFO_CONNECTIONINFO._serialized_start=7330
  _SUBSCRIPTIONINFO_CONNECTIONINFO._serialized_end=7655
  _SUBSCRIPTIONINFO_MEASUREMENT._serialized_start=7657
  _SUBSCRIPTIONINFO_MEASUREMENT._serialized_end=7698
  _REPLAYPARKEDREQ._serialized_start=7701
  _REPLAYPARKEDREQ._serialized_end=8047
  _REPLAYPARKEDREQ_OPTIONS._serialized_start=7808
  _REPLAYPARKEDREQ_OPTIONS._serialized_end=8047
  _REPLAYPARKEDRESP._serialized_start=8049
  _REPLAYPARKEDRESP._serialized_end=8067
  _LISTREQ._serialized_start=8070
  _LISTREQ._serialized_end=8472
  _LISTREQ_OPTIONS._serialized_start=8161
  _LISTREQ_OPTIONS._serialized_end=8340
  _LISTREQ_STREAMOPTION._serialized_start=8343
  _LISTREQ_STREAMOPTION._serialized_end=8472
  _LISTRESP._serialized_start=8474
  _LISTRESP._serialized_end=8570
  _PERSISTENTSUBSCRIPTIONS._serialized_start=8573
  _PERSISTENTSUBSCRIPTIONS._serialized_end=9547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import shared_pb2 as shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcluster.proto\x12\x13\x65vent_store.cluster\x1a\x0cshared.proto\"n\n\rGossipRequest\x12.\n\x04info\x18\x01 \x01(\x0b\x32 .event_store.cluster.ClusterInfo\x12-\n\x06server\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\"\x8c\x01\n\x11ViewChangeRequest\x12+\n\tserver_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x16\n\x0e\x61ttempted_view\x18\x03 \x01(\x05\"\x91\x01\n\x16ViewChangeProofRequest\x12+\n\tserver_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x16\n\x0einstalled_view\x18\x03 \x01(\x05\"\x7f\n\x0ePrepareRequest\x12+\n\tserver_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x0c\n\x04view\x18\x03 \x01(\x05\"\xba\x03\n\x10PrepareOkRequest\x12\x0c\n\x04view\x18\x01 \x01(\x05\x12+\n\tserver_id\x18\x02 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x03 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x14\n\x0c\x65poch_number\x18\x04 \x01(\x05\x12\x16\n\x0e\x65poch_position\x18\x05 \x01(\x03\x12*\n\x08\x65poch_id\x18\x06 \x01(\x0b\x32\x18.event_store.client.UUID\x12:\n\x18\x65poch_leader_instance_id\x18\x07 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x1c\n\x14last_commit_position\x18\x08 \x01(\x03\x12\x19\n\x11writer_checkpoint\x18\t \x01(\x03\x12\x19\n\x11\x63haser_checkpoint\x18\n \x01(\x03\x12\x15\n\rnode_priority\x18\x0b \x01(\x05\x12\x36\n\x0c\x63luster_info\x18\x0c \x01(\x0b\x32 .event_store.cluster.ClusterInfo\"\xe2\x03\n\x0fProposalRequest\x12+\n\tserver_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12+\n\tleader_id\x18\x03 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bleader_http\x18\x04 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x0c\n\x04view\x18\x05 \x01(\x05\x12\x14\n\x0c\x65poch_number\x18\x06 \x01(\x05\x12\x16\n\x0e\x65poch_position\x18\x07 \x01(\x03\x12*\n\x08\x65poch_id\x18\x08 \x01(\x0b\x32\x18.event_store.client.UUID\x12:\n\x18\x65poch_leader_instance_id\x18\t \x01(\x0b\x32\x18.event_store.client.UUID\x12\x1c\n\x14last_commit_position\x18\n \x01(\x03\x12\x19\n\x11writer_checkpoint\x18\x0b \x01(\x03\x12\x19\n\x11\x63haser_checkpoint\x18\x0c \x01(\x03\x12\x15\n\rnode_priority\x18\r \x01(\x05\"\xdf\x01\n\rAcceptRequest\x12+\n\tserver_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12+\n\tleader_id\x18\x03 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bleader_http\x18\x04 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x0c\n\x04view\x18\x05 \x01(\x05\"{\n\x18LeaderIsResigningRequest\x12+\n\tleader_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bleader_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\"\xde\x01\n\x1aLeaderIsResigningOkRequest\x12+\n\tleader_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bleader_http\x18\x02 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12+\n\tserver_id\x18\x03 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x32\n\x0bserver_http\x18\x04 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\"?\n\x0b\x43lusterInfo\x12\x30\n\x07members\x18\x01 \x03(\x0b\x32\x1f.event_store.cluster.MemberInfo\")\n\x08\x45ndPoint\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"\xf3\x07\n\nMemberInfo\x12-\n\x0binstance_id\x18\x01 \x01(\x0b\x32\x18.event_store.client.UUID\x12\x12\n\ntime_stamp\x18\x02 \x01(\x03\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.event_store.cluster.MemberInfo.VNodeState\x12\x10\n\x08is_alive\x18\x04 \x01(\x08\x12\x35\n\x0ehttp_end_point\x18\x05 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x33\n\x0cinternal_tcp\x18\x06 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x33\n\x0c\x65xternal_tcp\x18\x07 \x01(\x0b\x32\x1d.event_store.cluster.EndPoint\x12\x1d\n\x15internal_tcp_uses_tls\x18\x08 \x01(\x08\x12\x1d\n\x15\x65xternal_tcp_uses_tls\x18\t \x01(\x08\x12\x1c\n\x14last_commit_position\x18\n \x01(\x03\x12\x19\n\x11writer_checkpoint\x18\x0b \x01(\x03\x12\x19\n\x11\x63haser_checkpoint\x18\x0c \x01(\x03\x12\x16\n\x0e\x65poch_position\x18\r \x01(\x03\x12\x14\n\x0c\x65poch_number\x18\x0e \x01(\x05\x12*\n\x08\x65poch_id\x18\x0f \x01(\x0b\x32\x18.event_store.client.UUID\x12\x15\n\rnode_priority\x18\x10 \x01(\x05\x12\x1c\n\x14is_read_only_replica\x18\x11 \x01(\x08\x12#\n\x1b\x61\x64vertise_host_to_client_as\x18\x12 \x01(\t\x12(\n advertise_http_port_to_client_as\x18\x13 \x01(\r\x12\'\n\x1f\x61\x64vertise_tcp_port_to_client_as\x18\x14 \x01(\r\"\x9a\x02\n\nVNodeState\x12\x10\n\x0cInitializing\x10\x00\x12\x12\n\x0e\x44iscoverLeader\x10\x01\x12\x0b\n\x07Unknown\x10\x02\x12\x0e\n\nPreReplica\x10\x03\x12\x0e\n\nCatchingUp\x10\x04\x12\t\n\x05\x43lone\x10\x05\x12\x0c\n\x08\x46ollower\x10\x06\x12\r\n\tPreLeader\x10\x07\x12\n\n\x06Leader\x10\x08\x12\x0b\n\x07Manager\x10\t\x12\x10\n\x0cShuttingDown\x10\n\x12\x0c\n\x08Shutdown\x10\x0b\x12\x16\n\x12ReadOnlyLeaderless\x10\x0c\x12\x16\n\x12PreReadOnlyReplica\x10\r\x12\x13\n\x0fReadOnlyReplica\x10\x0e\x12\x13\n\x0fResigningLeader\x10\x0f\";\n\x0fReplicaLogWrite\x12\x14\n\x0clog_position\x18\x01 \x01(\x03\x12\x12\n\nreplica_id\x18\x02 \x01(\x0c\"$\n\x0cReplicatedTo\x12\x14\n\x0clog_position\x18\x01 \x01(\x03\"G\n\x05\x45poch\x12\x16\n\x0e\x65poch_position\x18\x01 \x01(\x03\x12\x14\n\x0c\x65poch_number\x18\x02 \x01(\x05\x12\x10\n\x08\x65poch_id\x18\x03 \x01(\x0c\"\xd8\x01\n\x10SubscribeReplica\x12\x14\n\x0clog_position\x18\x01 \x01(\x03\x12\x10\n\x08\x63hunk_id\x18\x02 \x01(\x0c\x12.\n\nLastEpochs\x18\x03 \x03(\x0b\x32\x1a.event_store.cluster.Epoch\x12\n\n\x02ip\x18\x04 \x01(\x0c\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x11\n\tleader_id\x18\x06 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x07 \x01(\x0c\x12\x15\n\ris_promotable\x18\x08 \x01(\x08\x12\x0f\n\x07version\x18\t \x01(\x05\"F\n\x18ReplicaSubscriptionRetry\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\"^\n\x11ReplicaSubscribed\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\x12\x1d\n\x15subscription_position\x18\x03 \x01(\x03\"o\n\x15ReplicaLogPositionAck\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\x0c\x12 \n\x18replication_log_position\x18\x02 \x01(\x03\x12\x1b\n\x13writer_log_position\x18\x03 \x01(\x03\"\x84\x01\n\x0b\x43reateChunk\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\x12\x1a\n\x12\x63hunk_header_bytes\x18\x03 \x01(\x0c\x12\x11\n\tfile_size\x18\x04 \x01(\x05\x12\x1a\n\x12is_completed_chunk\x18\x05 \x01(\x08\"\xb1\x01\n\x0cRawChunkBulk\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\x12\x1a\n\x12\x63hunk_start_number\x18\x03 \x01(\x05\x12\x18\n\x10\x63hunk_end_number\x18\x04 \x01(\x05\x12\x14\n\x0craw_position\x18\x05 \x01(\x05\x12\x11\n\traw_bytes\x18\x06 \x01(\x0c\x12\x16\n\x0e\x63omplete_chunk\x18\x07 \x01(\x08\"\xbc\x01\n\rDataChunkBulk\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\x12\x1a\n\x12\x63hunk_start_number\x18\x03 \x01(\x05\x12\x18\n\x10\x63hunk_end_number\x18\x04 \x01(\x05\x12\x1d\n\x15subscription_position\x18\x05 \x01(\x03\x12\x12\n\ndata_bytes\x18\x06 \x01(\x0c\x12\x16\n\x0e\x63omplete_chunk\x18\x07 \x01(\x08\"@\n\x12\x46ollowerAssignment\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\"=\n\x0f\x43loneAssignment\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\">\n\x10\x44ropSubscription\x12\x11\n\tleader_id\x18\x01 \x01(\x0c\x12\x17\n\x0fsubscription_id\x18\x02 \x01(\x0c\x32\x9d\x01\n\x06Gossip\x12N\n\x06Update\x12\".event_store.cluster.GossipRequest\x1a .event_store.cluster.ClusterInfo\x12\x43\n\x04Read\x12\x19.event_store.client.Empty\x1a .event_store.cluster.ClusterInfo2\xa9\x05\n\tElections\x12O\n\nViewChange\x12&.event_store.cluster.ViewChangeRequest\x1a\x19.event_store.client.Empty\x12Y\n\x0fViewChangeProof\x12+.event_store.cluster.ViewChangeProofRequest\x1a\x19.event_store.client.Empty\x12I\n\x07Prepare\x12#.event_store.cluster.PrepareRequest\x1a\x19.event_store.client.Empty\x12M\n\tPrepareOk\x12%.event_store.cluster.PrepareOkRequest\x1a\x19.event_store.client.Empty\x12K\n\x08Proposal\x12$.event_store.cluster.ProposalRequest\x1a\x19.event_store.client.Empty\x12G\n\x06\x41\x63\x63\x65pt\x12\".event_store.cluster.AcceptRequest\x1a\x19.event_store.client.Empty\x12]\n\x11LeaderIsResigning\x12-.event_store.cluster.LeaderIsResigningRequest\x1a\x19.event_store.client.Empty\x12\x61\n\x13LeaderIsResigningOk\x12/.event_store.cluster.LeaderIsResigningOkRequest\x1a\x19.event_store.client.EmptyB\'\n%com.eventstore.dbclient.proto.clusterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.eventstore.dbclient.proto.cluster'
  _GOSSIPREQUEST._serialized_start=52
  _GOSSIPREQUEST._serialized_end=162
  _VIEWCHANGEREQUEST._serialized_start=165
  _VIEWCHANGEREQUEST._serialized_end=305
  _VIEWCHANGEPROOFREQUEST._serialized_start=308
  _VIEWCHANGEPROOFREQUEST._serialized_end=453
  _PREPAREREQUEST._serialized_start=455
  _PREPAREREQUEST._serialized_end=582
  _PREPAREOKREQUEST._serialized_start=585
  _PREPAREOKREQUEST._serialized_end=1027
  _PROPOSALREQUEST._serialized_start=1030
  _PROPOSALREQUEST._serialized_end=1512
  _ACCEPTREQUEST._serialized_start=1515
  _ACCEPTREQUEST._serialized_end=1738
  _LEADERISRESIGNINGREQUEST._serialized_start=1740
  _LEADERISRESIGNINGREQUEST._serialized_end=1863
  _LEADERISRESIGNINGOKREQUEST._serialized_start=1866
  _LEADERISRESIGNINGOKREQUEST._serialized_end=2088
  _CLUSTERINFO._serialized_start=2090
  _CLUSTERINFO._serialized_end=2153
  _ENDPOINT._serialized_start=2155
  _ENDPOINT._serialized_end=2196
  _MEMBERINFO._serialized_start=2199
  _MEMBERINFO._serialized_end=3210
  _MEMBERINFO_VNODESTATE._serialized_start=2928
  _MEMBERINFO_VNODESTATE._serialized_end=3210
  _REPLICALOGWRITE._serialized_start=3212
  _REPLICALOGWRITE._serialized_end=3271
  _REPLICATEDTO._serialized_start=3273
  _REPLICATEDTO._serialized_end=3309
  _EPOCH._serialized_start=3311
  _EPOCH._serialized_end=3382
  _SUBSCRIBEREPLICA._serialized_start=3385
  _SUBSCRIBEREPLICA._serialized_end=3601
  _REPLICASUBSCRIPTIONRETRY._serialized_start=3603
  _REPLICASUBSCRIPTIONRETRY._serialized_end=3673
  _REPLICASUBSCRIBED._serialized_start=3675
  _REPLICASUBSCRIBED._serialized_end=3769
  _REPLICALOGPOSITIONACK._serialized_start=3771
  _REPLICALOGPOSITIONACK._serialized_end=3882
  _CREATECHUNK._serialized_start=3885
  _CREATECHUNK._serialized_end=4017
  _RAWCHUNKBULK._serialized_start=4020
  _RAWCHUNKBULK._serialized_end=4197
  _DATACHUNKBULK._serialized_start=4200
  _DATACHUNKBULK._serialized_end=4388
  _FOLLOWERASSIGNMENT._serialized_start=4390
  _FOLLOWERASSIGNMENT._serialized_end=4454
  _CLONEASSIGNMENT._serialized_start=4456
  _CLONEASSIGNMENT._serialized_end=4517
  _DROPSUBSCRIPTION._serialized_start=4519
  _DROPSUBSCRIPTION._serialized_end=4581
  _GOSSIP._serialized_start=4584
  _GOSSIP._serialized_end=4741
  _ELECTIONS._serialized_start=4744
  _ELECTIONS._serialized_end=5425
# @@protoc_insertion_point(module_scope)
